/* styles.css */

/* スイッチのスタイル */
.apple-toggle-container {
    margin-bottom: 10px;
  }
  
  .apple-toggle {
    display: flex;
    align-items: center;
    cursor: pointer;
    position: relative;
  }
  
  .apple-toggle input {
    opacity: 0;
    position: absolute;
    cursor: pointer;
    width: 0;
    height: 0;
  }
  
  .apple-toggle .slider {
    position: relative;
    display: inline-block;
    width: 34px;
    height: 20px;
    background-color: #ccc;
    border-radius: 50px;
    transition: background-color 0.3s;
  }
  
  .apple-toggle .slider:before {
    content: "";
    position: absolute;
    height: 12px;
    width: 12px;
    border-radius: 50%;
    background-color: white;
    transition: transform 0.3s;
    top: 4px;
    left: 4px;
  }
  
  .apple-toggle input:checked + .slider {
    background-color: #4CAF50; /* ON時の色 */
  }
  
  .apple-toggle input:checked + .slider:before {
    transform: translateX(14px); /* スライドする位置 */
  }
  
  .apple-toggle .label {
    margin-left: 10px;
  }
  
  /* テキストボックスのスタイル */
  textarea.multiline-textarea {
    width: 100%;
    height: 300px;
    box-sizing: border-box;
  }

  input[readonly], textarea[readonly] {
    background-color: white;
    pointer-events: none;
    border: 1px solid #ccc;
  }
